==> apimodule-1.0.2.tar.gz: lib/api/simpersaa/auth_service.dart <==
import 'dart:convert';
import 'dart:io';

import 'package:http/http.dart' as http;
import 'package:apimodule/api/config/endpoint.dart';
import 'package:apimodule/api/config/apisettings.dart';
import 'package:apimodule/model/request/change_password_request.dart';
import 'package:apimodule/model/request/login_request.dart';
import 'package:apimodule/model/request/save_token_request.dart';
import 'package:apimodule/model/response/global_response.dart';
import 'package:apimodule/model/response/login_response.dart';

class AuthService {
  static Future<dynamic> saveToken(SaveTokenRequest request) async {
    var tokenRequest = new Map<String, dynamic>();
    tokenRequest['nip_nik'] = request.nipNik;
    tokenRequest['device_id'] = request.deviceId;
    tokenRequest['token'] = request.token;

    try {
      final response = await http.post(
        EndpointSimpersaa.token,
        headers: null,
        body: tokenRequest,
      );
      if (response.statusCode == 200) {
        final body = jsonDecode(response.body);
        return GlobalResponse.fromJson(body);
      } else {
        return GlobalResponse(msg: APiSettings.errorMsg);
      }
    } on SocketException {
      return GlobalResponse(msg: APiSettings.errorNetwork);
    }
  }

  static Future<dynamic> fetchLogin(LoginRequest request) async {
    var loginRequest = new Map<String, dynamic>();
    loginRequest['kodeAkun'] = request.kodeAkun;
    loginRequest['password'] = request.password;
    loginRequest['device'] = request.device;

    try {
      final response = await http.post(
        EndpointSimpersaa.login,
        headers: null,
        body: loginRequest,
      );
      if (response.statusCode == 200) {
        final body = jsonDecode(response.body);
        return LoginResponse.fromJson(body);
      } else {
        return GlobalResponse(msg: APiSettings.errorMsg);
      }
    } on SocketException {
      return GlobalResponse(msg: APiSettings.errorNetwork);
    }
  }

  static Future<dynamic> fetchChangePassword(
      ChangePasswordRequest request) async {
    var cpRequest = new Map<String, dynamic>();
    cpRequest['nip'] = request.nip;
    cpRequest['password_lama'] = request.passwordLama;
    cpRequest['password_baru'] = request.passwordBaru;
    cpRequest['password_confirm'] = request.passwordConfirm;

    try {
      final response = await http.post(
        EndpointSimpersaa.changePassword,
        headers: null,
        body: cpRequest,
      );
      if (response.statusCode == 200) {
        final body = jsonDecode(response.body);
        return LoginResponse.fromJson(body);
      } else {
        return GlobalResponse(msg: APiSettings.errorMsg);
      }
    } on SocketException {
      return GlobalResponse(msg: APiSettings.errorNetwork);
    }
  }
}

==> apimodule-1.0.5.tar.gz: lib/api/simpersaa/auth_service.dart <==
import 'dart:convert';
import 'dart:io';

import 'package:http/http.dart' as http;
import 'package:apimodule/api/config/endpoint.dart';
import 'package:apimodule/api/config/apisettings.dart';
import 'package:apimodule/msimpersaa/request/change_password_request.dart';
import 'package:apimodule/msimpersaa/request/login_request.dart';
import 'package:apimodule/msimpersaa/request/save_token_request.dart';
import 'package:apimodule/msimpersaa/response/global_response.dart';
import 'package:apimodule/msimpersaa/response/login_response.dart';

class AuthService {
  static Future<dynamic> saveToken(SaveTokenRequest request) async {
    var tokenRequest = new Map<String, dynamic>();
    tokenRequest['nip_nik'] = request.nipNik;
    tokenRequest['device_id'] = request.deviceId;
    tokenRequest['token'] = request.token;

    try {
      final response = await http.post(
        EndpointSimpersaa.token,
        headers: null,
        body: tokenRequest,
      );
      if (response.statusCode == 200) {
        final body = jsonDecode(response.body);
        return GlobalResponse.fromJson(body);
      } else {
        return GlobalResponse(msg: APiSettings.errorMsg);
      }
    } on SocketException {
      return GlobalResponse(msg: APiSettings.errorNetwork);
    }
  }

  static Future<dynamic> fetchLogin(LoginRequest request) async {
    var loginRequest = new Map<String, dynamic>();
    loginRequest['kodeAkun'] = request.kodeAkun;
    loginRequest['password'] = request.password;
    loginRequest['device'] = request.device;

    try {
      final response = await http.post(
        EndpointSimpersaa.login,
        headers: null,
        body: loginRequest,
      );
      if (response.statusCode == 200) {
        final body = jsonDecode(response.body);
        return LoginResponse.fromJson(body);
      } else {
        return GlobalResponse(msg: APiSettings.errorMsg);
      }
    } on SocketException {
      return GlobalResponse(msg: APiSettings.errorNetwork);
    }
  }

  static Future<dynamic> fetchChangePassword(
      ChangePasswordRequest request) async {
    var cpRequest = new Map<String, dynamic>();
    cpRequest['nip'] = request.nip;
    cpRequest['password_lama'] = request.passwordLama;
    cpRequest['password_baru'] = request.passwordBaru;
    cpRequest['password_confirm'] = request.passwordConfirm;

    try {
      final response = await http.post(
        EndpointSimpersaa.changePassword,
        headers: null,
        body: cpRequest,
      );
      if (response.statusCode == 200) {
        final body = jsonDecode(response.body);
        return LoginResponse.fromJson(body);
      } else {
        return GlobalResponse(msg: APiSettings.errorMsg);
      }
    } on SocketException {
      return GlobalResponse(msg: APiSettings.errorNetwork);
    }
  }
}
